function [uz,urho]=mogi_point(dV,d,nu,rho)
% 
% dV    volume change
% d 	depth to center of source
% nu    Poisson's ratio
% rho   radial horizontal distance from source
% 
% uz 	vertical displacement at surface
% urho  horizontal radial displacement 

front = (dV.*(1-nu)/pi);

uz = front*(d./((rho.^2 + d.^2).^(3/2)));
urho = front*(rho./((rho.^2 + d.^2).^(3/2)));



